safe_capacity_percentage = 100
media_shares = "/Users/steve/Desktop/Media"

logfile = "transmission.log"
download_path = "~/Downloads"
unrar_path = "/usr/local/bin/unrar"

regex_movie = "^(.+).(\d{4}).+(240p|480p|720p|1080p|2160p).+$"
regex_tv = "^(.+).(S(\d+)E(\d+)).+$"
share_tv_root_path = "%s/TV/%s"
share_tv_season_path = "%s/TV/%s/Season %s"
share_movie_root_path = "%s/Movies/%s"
